==> wevue-2.1.4.tgz: package/lib/create_page.js <==
var path = require('path');
var fs = require('fs');
var fse = require('fs-extra');
var debug = require('debug')('wevue');
/*
创建页面三个文件 page.js page.wxml page.wxss
*/

module.exports = function(appFolder, wevueFolder, pageckageFile) {

    try {
        var jsTemplateFile = path.join(wevueFolder, 'template', 'page', 'page.js');
        var wxmlTemplateFile = path.join(wevueFolder, 'template', 'page', 'page.wxml');
        var wxssTemplateFile = path.join(wevueFolder, 'template', 'page', 'page.wxss');

        var packageContent = fs.readFileSync(pageckageFile, 'utf8');
        var packageJSON = JSON.parse(packageContent);
        var pages = packageJSON.pages || [];
        debug('pages', pages);
        for (var i = 0; i < pages.length; i++) {
            var page = pages[i];

            var jsFile = path.join(appFolder, page + ".js");

            var pathInfo = path.parse(jsFile);

            if (!fs.existsSync(pathInfo.dir)) {
                fse.mkdirsSync(pathInfo.dir);
            }

            if (!fs.existsSync(jsFile)) {
                fs.writeFileSync(jsFile, fs.readFileSync(jsTemplateFile, 'utf8'));
            }

            var wxssFile = path.join(appFolder, page + ".wxss");
            if (!fs.existsSync(wxssFile)) {
                fs.writeFileSync(wxssFile, fs.readFileSync(wxssTemplateFile, 'utf8'));
            }

            var wxmlFile = path.join(appFolder, page + ".wxml");
            if (!fs.existsSync(wxmlFile)) {
                fs.writeFileSync(wxmlFile, fs.readFileSync(wxmlTemplateFile, 'utf8'));
            }
        }

    } catch (e) {
        console.log(e.stack)
    } finally {

    }

}

==> wevue-2.2.5.tgz: package/lib/create_page.js <==
var path = require('path');
var fs = require('fs');
var fse = require('fs-extra');
var debug = require('debug')('wevue');
/*
创建页面三个文件 page.js page.wxml page.wxss
*/

module.exports = function(appFolder, wevueFolder, pageckageFile, program) {

    try {
        var templateFolder = 'template'
        if (program.ver == 2) {
            templateFolder = templateFolder + '2'
        }

        var jsTemplateFile = path.join(wevueFolder, templateFolder, 'page', 'page.js');
        var wxmlTemplateFile = path.join(wevueFolder, templateFolder, 'page', 'page.wxml');
        var wxssTemplateFile = path.join(wevueFolder, templateFolder, 'page', 'page.wxss');

        var packageContent = fs.readFileSync(pageckageFile, 'utf8');
        var packageJSON = JSON.parse(packageContent);
        var pages = packageJSON.pages || [];
        debug('pages', pages);
        for (var i = 0; i < pages.length; i++) {
            var page = pages[i];

            var jsFile = path.join(appFolder, page + ".js");

            var pathInfo = path.parse(jsFile);

            if (!fs.existsSync(pathInfo.dir)) {
                fse.mkdirsSync(pathInfo.dir);
            }

            if (!fs.existsSync(jsFile)) {
                fs.writeFileSync(jsFile, fs.readFileSync(jsTemplateFile, 'utf8'));
            }

            var wxssFile = path.join(appFolder, page + ".wxss");
            if (!fs.existsSync(wxssFile)) {
                fs.writeFileSync(wxssFile, fs.readFileSync(wxssTemplateFile, 'utf8'));
            }

            var wxmlFile = path.join(appFolder, page + ".wxml");
            if (!fs.existsSync(wxmlFile)) {
                fs.writeFileSync(wxmlFile, fs.readFileSync(wxmlTemplateFile, 'utf8'));
            }
        }

    } catch (e) {
        console.log(e.stack)
    } finally {

    }

}
